@@ -1,5 +1,6 @@
-import os, argparse
+import os, argparse, logging
 from pathlib import Path
+
 from animo_trainer import __version__
 
 ASCII_LOGO = f"""
@@ -25,7 +26,6 @@ parser.add_argument(
     action='version', version=f"%(prog)s {__version__}"
 )
 
-
 def main():
     parsed_args = parser.parse_args()
     print(ASCII_LOGO)
@@ -79,15 +79,19 @@ def main():
 
         if not override_path:
             clr.AddReference(base_dll)
-        else:
-            override_dll = os.path.join(override_path, dll_name)
+            return
 
-            if os.path.isfile(override_dll):
-                clr.AddReference(override_dll)
-            elif os.path.isfile(base_dll):
-                clr.AddReference(base_dll)
-            else:
-                raise ValueError(f"Missing important dll: {dll_name}")
+        override_dll = os.path.join(override_path, dll_name)
+
+        if os.path.isfile(override_dll):
+            clr.AddReference(override_dll)
+            return
+
+        if os.path.isfile(base_dll):
+            clr.AddReference(base_dll)
+            return
+
+        raise ValueError(f"Missing important dll: {dll_name}")
 
     current_dir = pathlib.Path(__file__).parent.resolve()
     animo_unity_dll_dir = os.path.realpath(os.path.join(current_dir, "lib"))
@@ -100,6 +104,9 @@ def main():
     load_dll(animo_unity_dll_dir, dll_dir_override, "AnimoSimulation.dll")
     load_dll(animo_unity_dll_dir, dll_dir_override, "AnimoData.dll")
 
+    from TransformsAI.Animo.Tools import AnimoLogger
+    AnimoLogger.RegisterLogger(AnimoLogger.StandardLogger)
+
     from animo_trainer.animo_training_session import AnimoTrainingSession
     from animo_trainer.animo_trainer_controller import AnimoTrainingController
     from animo_trainer.animo_stats_writers import register_animo_stats_writers
@@ -120,7 +127,7 @@ def main():
     try:
         pythonnet.unload()
     except Exception as e:
-        print(e)
+        logging.exception(e)
     print(f"Animo-Learn::Stopped")
 
 
